summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_remote_scheduler.py
diff options
context:
space:
mode:
authorMattia Rizzolo <mattia@debian.org>2017-04-11 20:55:48 +0200
committerMattia Rizzolo <mattia@debian.org>2017-04-11 20:55:55 +0200
commite32380742425313817f235ed1774a45ea9c2752f (patch)
treeb5c035a6d17157878d44bb92906fb49e007754fe /bin/reproducible_remote_scheduler.py
parentd0db59ed0007fa7612d66c628bb59d275432c825 (diff)
downloadjenkins.debian.net-e32380742425313817f235ed1774a45ea9c2752f.tar.xz
reproducible debian: temporarily rise the schedule limit (again)
Signed-off-by: Mattia Rizzolo <mattia@debian.org>
Diffstat (limited to 'bin/reproducible_remote_scheduler.py')
-rwxr-xr-xbin/reproducible_remote_scheduler.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_remote_scheduler.py b/bin/reproducible_remote_scheduler.py
index cd1eaad6..2164bbb6 100755
--- a/bin/reproducible_remote_scheduler.py
+++ b/bin/reproducible_remote_scheduler.py
@@ -212,7 +212,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
log.debug('date_scheduled = ' + date + ' time_delta = ' + str(time_delta))
# a single person can't schedule more than 200 packages in the same day; this
# is actually easy to bypass, but let's give some trust to the Debian people
query = """SELECT count(*) FROM manual_scheduler
WHERE requester = '{}' AND date_request > '{}'"""
@@ -221,7 +221,7 @@ try:
except IndexError:
amount = 0
log.debug(requester + ' already scheduled ' + str(amount) + ' packages today')
-if amount + len(ids) > 200 and not local:
+if amount + len(ids) > 2000 and not local:
log.error(bcolors.FAIL + 'You have exceeded the maximum number of manual ' +
'reschedulings allowed for a day. Please ask in ' +
'#debian-reproducible if you need to schedule more packages.' +
@@ -212,7 +212,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
log.debug('date_scheduled = ' + date + ' time_delta = ' + str(time_delta))
-# a single person can't schedule more than 200 packages in the same day; this
+# a single person can't schedule more than 2000 packages in the same day; this
# is actually easy to bypass, but let's give some trust to the Debian people
query = """SELECT count(*) FROM manual_scheduler